import h5py
from h5schemas.scan_schema import GroupDefinition
from h5schemas.h5_types.number import NumberDataset
from h5schemas.h5_types.integer import IntegerDataset
from h5schemas.h5_types.string import StringDataset
from h5schemas.h5_types.image import ImageDataset


NONE = "null"


def initialize_dataset(main_file: h5py.File, datasets: list[GroupDefinition]):
    for dataset in datasets:
        if dataset.type == "number":
            dst = NumberDataset.with_file(dataset, main_file)
        elif dataset.type == "integer":
            dst = IntegerDataset.with_file(dataset, main_file)
        elif dataset.type == "string":
            dst = StringDataset.with_file(dataset, main_file)
        elif dataset.type == "image":
            dst = ImageDataset.with_file(dataset, main_file)

        dst.dataset.attrs["required"] = dataset.required

        if isinstance(dst, (IntegerDataset, NumberDataset)):
            dst.dataset.attrs["minimum"] = (
                dst.minimum if dst.minimum is not None else NONE
            )
            dst.dataset.attrs["maximum"] = (
                dst.maximum if dst.minimum is not None else NONE
            )
